[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
01/02: berlin: Add Onion service for guix.gnu.org.
From: |
Ludovic Courtès |
Subject: |
01/02: berlin: Add Onion service for guix.gnu.org. |
Date: |
Fri, 18 Mar 2022 18:07:36 -0400 (EDT) |
civodul pushed a commit to branch master
in repository maintenance.
commit c817e2ce343bdd1c88242596afcee3bc0682a4b5
Author: Ludovic Courtès <ludo@gnu.org>
AuthorDate: Fri Mar 18 23:02:06 2022 +0100
berlin: Add Onion service for guix.gnu.org.
* hydra/berlin.scm (services): Add 'tor-hidden-service' for guix.gnu.org.
---
hydra/berlin.scm | 10 ++++++++--
1 file changed, 8 insertions(+), 2 deletions(-)
diff --git a/hydra/berlin.scm b/hydra/berlin.scm
index 10e1e9b..dad2ac8 100644
--- a/hydra/berlin.scm
+++ b/hydra/berlin.scm
@@ -1,6 +1,6 @@
;; OS configuration for "berlin", the frontend of the compile farm
;; hosted at the MDC.
-;; Copyright © 2016, 2017, 2018, 2019, 2020, 2021 Ludovic Courtès
<ludo@gnu.org>
+;; Copyright © 2016-2022 Ludovic Courtès <ludo@gnu.org>
;; Copyright © 2017, 2018, 2019, 2020, 2021 Ricardo Wurmus <rekado@elephly.net>
;; Copyright © 2019, 2021 Julien Lepiller <julien@lepiller.eu>
;; Copyright © 2020, 2021 Florian Pelz <pelzflorian@pelzflorian.de>
@@ -358,11 +358,17 @@ Happy hacking!\n"))
(service ntp-service-type)
;; Make SSH and HTTP/HTTPS available over Tor.
(tor-hidden-service "http"
'((22 "127.0.0.1:22")
(80 "127.0.0.1:80")
(443 "127.0.0.1:443")))
+
+ ;; Onion service for the web site.
+ (tor-hidden-service "guix.gnu.org"
+ '((80 "127.0.0.1:80")
+ (443 "127.0.0.1:443")))
+
(service tor-service-type)
(service nginx-service-type %nginx-configuration)
@@ -358,11 +358,17 @@ Happy hacking!\n"))
(service ntp-service-type)
- ;; Make SSH and HTTP/HTTPS available over Tor.
+ ;; Make SSH and ci.guix available over Tor.
(tor-hidden-service "http"
'((22 "127.0.0.1:22")